@@ -23,7 +23,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 # Preloaded methods go here.
@@ -362,8 +362,15 @@ An advanced example which creates a timer with AnyEvent.
  * equal : for all objects.
 
  * . : (.[perl namespace] method args ...)
+        method name can be specifed with sigils to control what type of value should be passed into perl function.
+        ^[$@%!\\]?method[$@%\\]+
+        $ : scalar
+        @ : array
+        % : hash
+        ! : nil
 
 	(.CljPerl print "foo")
+	(.CljPerl !print$ "foo") ; return nil and pass first argument as a scalar
 
  * -> : (->[perl namespace] method args ...)
    Like '.', but this will pass perl namespace as first argument to perl method.
